django-styleguide
=================

[![Build Status](https://travis-ci.org/andrefarzat/django-styleguide.png?branch=master)](https://travis-ci.org/andrefarzat/django-styleguide)
[![Coverage Status](https://coveralls.io/repos/andrefarzat/django-styleguide/badge.png?branch=master)](https://coveralls.io/r/andrefarzat/django-styleguide?branch=master)
[![Requirements Status](https://requires.io/github/andrefarzat/django-styleguide/requirements.png?branch=master)](https://requires.io/github/andrefarzat/django-styleguide/requirements/?branch=master)

styleguide for django




Executing the tests
-------------------

`python manage.py test`